==> razorqt_0.4.1.orig.tar.xz: razorqt-0.4.1/libraries/razorqt/translations/librazorqt_sk_SK.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>AddPluginDialog</name>
    <message>
        <source>Add plugins</source>
        <translation>Pridať zásuvné moduly</translation>
    </message>
    <message>
        <source>Search:</source>
        <translation>Hľadať:</translation>
    </message>
    <message>
        <source>Add plugin</source>
        <translation>Pridať zásuvný modul</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Zatvoriť</translation>
    </message>
</context>
<context>
    <name>Battery</name>
    <message>
        <source>%1 : Properties changed</source>
        <translation>%1 : Vlastnosti sa zmenili</translation>
    </message>
    <message>
        <source>%1 : Low</source>
        <translation>%1 : Takmer vybitá</translation>
    </message>
    <message>
        <source>%1 : Full</source>
        <translation>%1 : Nabitá</translation>
    </message>
</context>
<context>
    <name>PowerManager</name>
    <message>
        <source>Hibernate</source>
        <translation>Hibernovať</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Úsporný režim</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Reštartovať</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Vypnúť</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Odhlásiť sa</translation>
    </message>
    <message>
        <source>Razor Session Suspend</source>
        <translation>Úsporný režim relácie Razor</translation>
    </message>
    <message>
        <source>Do you want to really suspend your computer?&lt;p&gt;Suspends the computer into a low power state. System state is not preserved if the power is lost.</source>
        <translation>Skutočne chcete svoj počítač uviesť do úsporného režimu?&lt;p&gt;Uvedie počítač do stavu s nízkym odberom prúdu. Stav systému sa pri strate napájania nezachová.</translation>
    </message>
    <message>
        <source>Razor Session Hibernate</source>
        <translation>Hibernácia relácie Razor</translation>
    </message>
    <message>
        <source>Do you want to really hibernate your computer?&lt;p&gt;Hibernates the computer into a low power state. System state is preserved if the power is lost.</source>
        <translation>Skutočne chcete svoj počítač hibernovať?&lt;p&gt;Uvedie počítač do stavu s nízkym odberom prúdu. Stav systému sa pri strate napájania zachová.</translation>
    </message>
    <message>
        <source>Razor Session Reboot</source>
        <translation>Reštart relácie Razor</translation>
    </message>
    <message>
        <source>Do you want to really restart your computer? All unsaved work will be lost...</source>
        <translation>Skutočne chcete svoj počítač reštartovať? Akákoľvek neuložená práca sa stratí...</translation>
    </message>
    <message>
        <source>Razor Session Shutdown</source>
        <translation>Vypnutie relácie Razor</translation>
    </message>
    <message>
        <source>Do you want to really switch off your computer? All unsaved work will be lost...</source>
        <translation>Skutočne chcete svoj počítač vypnúť? Akákoľvek neuložená práca sa stratí...</translation>
    </message>
    <message>
        <source>Razor Session Logout</source>
        <translation>Odhlásenie relácie Razor</translation>
    </message>
    <message>
        <source>Do you want to really logout? All unsaved work will be lost...</source>
        <translation>Skutočne sa chcete odhlásiť z vášho počítača? Akákoľvek neuložená práca sa stratí...</translation>
    </message>
    <message>
        <source>Razor Power Manager Error</source>
        <translation>Chyba správcu napájania Razor</translation>
    </message>
    <message>
        <source>Hibernate failed.</source>
        <translation>Hibernácia sa nepodarila.</translation>
    </message>
    <message>
        <source>Suspend failed.</source>
        <translation>Uvedenie do úsporného režimu sa nepodarilo.</translation>
    </message>
</context>
<context>
    <name>RazorShortcutButton</name>
    <message>
        <source>Clear</source>
        <translation>Vyčistiť</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Žiadna</translation>
    </message>
</context>
<context>
    <name>ScreenSaver</name>
    <message>
        <source>Lock Screen</source>
        <translation>Zamknúť obrazovku</translation>
    </message>
    <message>
        <source>Screen Saver Activation Error</source>
        <translation>CHyba pri aktivácii šetriča obrazovky</translation>
    </message>
    <message>
        <source>An error occurred starting screensaver. xdg-screensaver cannot be started due its crash.</source>
        <translation>Pri štarte šetriča obrazovky sa vyskytla chyba. xdg-screensaver nebolo možné spustiť, pretože havaroval.</translation>
    </message>
    <message>
        <source>An error occurred starting screensaver. xdg-screensaver is not installed correctly.</source>
        <translation>Pri štarte šetriča obrazovky sa vyskytla chyba. xdg-screensaver nie je správne nainštalovaný.</translation>
    </message>
    <message>
        <source>An error occurred starting screensaver. xdg-screensaver cannot be started.</source>
        <translation>Pri štarte šetriča obrazovky sa vyskytla chyba. xdg-screensaver nebolo možné spustiť.</translation>
    </message>
    <message>
        <source>An error occurred starting screensaver. Syntax error in xdg-screensaver arguments.</source>
        <translation>Pri štarte šetriča obrazovky sa vyskytla chyba. Chyba syntaxe v argumentoch xdg-screensaver.</translation>
    </message>
    <message>
        <source>An error occurred starting screensaver. Ensure you have xscreensaver installed and running.</source>
        <translation>Pri štarte šetriča obrazovky sa vyskytla chyba. Uistite sa, či je xdg-screensaver nainštalovaný a spustený.</translation>
    </message>
    <message>
        <source>An error occurred starting screensaver. Action &apos;activate&apos; failed. Ensure you have xscreensaver installed and running.</source>
        <translation>Pri štarte šetriča obrazovky sa vyskytla chyba. Operácia „activate“ zlyhala. Uistite sa, či je xdg-screensaver nainštalovaný a spustený.</translation>
    </message>
    <message>
        <source>An error occurred starting screensaver. Unkown error - undocumented return value from xdg-screensaver=%1.</source>
        <translation>Pri štarte šetriča obrazovky sa vyskytla chyba. Neznáma chyba - xdg-screensaver vrátil nezdokumentovanú návratovú hodnotu „%1“.</translation>
    </message>
</context>
<context>
    <name>about</name>
    <message>
        <source> About Razor</source>
        <translation>O prostredí Razor</translation>
    </message>
</context>
</TS>

==> razorqt_0.5.2.orig.tar.xz: razorqt-0.5.2/libraries/razorqt/translations/librazorqt_sk_SK.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="sk_SK" version="2.0">
<context>
    <name>AddPluginDialog</name>
    <message>
        <source>Add plugins</source>
        <translation>Pridať zásuvné moduly</translation>
    </message>
    <message>
        <source>Search:</source>
        <translation>Hľadať:</translation>
    </message>
    <message>
        <source>Add plugin</source>
        <translation>Pridať zásuvný modul</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Zatvoriť</translation>
    </message>
</context>
<context>
    <name>PowerManager</name>
    <message>
        <source>Hibernate</source>
        <translation>Hibernovať</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Úsporný režim</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Reštartovať</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Vypnúť</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Odhlásiť sa</translation>
    </message>
    <message>
        <source>Razor Session Suspend</source>
        <translation>Úsporný režim relácie Razor</translation>
    </message>
    <message>
        <source>Do you want to really suspend your computer?&lt;p&gt;Suspends the computer into a low power state. System state is not preserved if the power is lost.</source>
        <translation>Skutočne chcete svoj počítač uviesť do úsporného režimu?&lt;p&gt;Uvedie počítač do stavu s nízkym odberom prúdu. Stav systému sa pri strate napájania nezachová.</translation>
    </message>
    <message>
        <source>Razor Session Hibernate</source>
        <translation>Hibernácia relácie Razor</translation>
    </message>
    <message>
        <source>Do you want to really hibernate your computer?&lt;p&gt;Hibernates the computer into a low power state. System state is preserved if the power is lost.</source>
        <translation>Skutočne chcete svoj počítač hibernovať?&lt;p&gt;Uvedie počítač do stavu s nízkym odberom prúdu. Stav systému sa pri strate napájania zachová.</translation>
    </message>
    <message>
        <source>Razor Session Reboot</source>
        <translation>Reštart relácie Razor</translation>
    </message>
    <message>
        <source>Do you want to really restart your computer? All unsaved work will be lost...</source>
        <translation>Skutočne chcete svoj počítač reštartovať? Akákoľvek neuložená práca sa stratí...</translation>
    </message>
    <message>
        <source>Razor Session Shutdown</source>
        <translation>Vypnutie relácie Razor</translation>
    </message>
    <message>
        <source>Do you want to really switch off your computer? All unsaved work will be lost...</source>
        <translation>Skutočne chcete svoj počítač vypnúť? Akákoľvek neuložená práca sa stratí...</translation>
    </message>
    <message>
        <source>Razor Session Logout</source>
        <translation>Odhlásenie relácie Razor</translation>
    </message>
    <message>
        <source>Do you want to really logout? All unsaved work will be lost...</source>
        <translation>Skutočne sa chcete odhlásiť z vášho počítača? Akákoľvek neuložená práca sa stratí...</translation>
    </message>
    <message>
        <source>Razor Power Manager Error</source>
        <translation>Chyba správcu napájania Razor</translation>
    </message>
    <message>
        <source>Hibernate failed.</source>
        <translation>Hibernácia sa nepodarila.</translation>
    </message>
    <message>
        <source>Suspend failed.</source>
        <translation>Uvedenie do úsporného režimu sa nepodarilo.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Power Manager Error</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>QDBusInterface is invalid</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Power Manager Error (D-BUS call)</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>RazorAboutDLGPrivate</name>
    <message>
        <source>Version: %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Advanced, easy-to-use, and fast desktop environment based on Qt technologies.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Copyright: %1-%2 %3</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Homepage: %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>License: %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Razor-qt is developed by the &lt;a %1&gt;Razor-qt Team and contributors&lt;/a&gt; on Github.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>If you are interested in working with our development team, &lt;a %1&gt;join us&lt;/a&gt;.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Special thanks to:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Razor-qt is translated into many languages thanks to the work of the translation teams all over the world.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Yes</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>No</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&lt;b&gt;Razor Desktop Toolbox - Technical Info&lt;/b&gt;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Version</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Qt</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Debug Build</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>System Configuration</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Share Directory</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Translations</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&lt;b&gt;User Directories&lt;/b&gt;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Xdg Data Home</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Xdg Config Home</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Xdg Data Dirs</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Xdg Cache Home</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Xdg Runtime Home</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Xdg Autostart Dirs</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Xdg Autostart Home</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>RazorConfigDialog</name>
    <message>
        <source>Dialog</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>RazorNotificationPrivate</name>
    <message>
        <source>Notifications Fallback</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>RazorShortcutButton</name>
    <message>
        <source>Clear</source>
        <translation>Vyčistiť</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Žiadna</translation>
    </message>
</context>
<context>
    <name>ScreenSaver</name>
    <message>
        <source>Lock Screen</source>
        <translation>Zamknúť obrazovku</translation>
    </message>
    <message>
        <source>Screen Saver Activation Error</source>
        <translation>CHyba pri aktivácii šetriča obrazovky</translation>
    </message>
    <message>
        <source>An error occurred starting screensaver. xdg-screensaver cannot be started due its crash.</source>
        <translation>Pri štarte šetriča obrazovky sa vyskytla chyba. xdg-screensaver nebolo možné spustiť, pretože havaroval.</translation>
    </message>
    <message>
        <source>An error occurred starting screensaver. xdg-screensaver is not installed correctly.</source>
        <translation>Pri štarte šetriča obrazovky sa vyskytla chyba. xdg-screensaver nie je správne nainštalovaný.</translation>
    </message>
    <message>
        <source>An error occurred starting screensaver. xdg-screensaver cannot be started.</source>
        <translation>Pri štarte šetriča obrazovky sa vyskytla chyba. xdg-screensaver nebolo možné spustiť.</translation>
    </message>
    <message>
        <source>An error occurred starting screensaver. Syntax error in xdg-screensaver arguments.</source>
        <translation>Pri štarte šetriča obrazovky sa vyskytla chyba. Chyba syntaxe v argumentoch xdg-screensaver.</translation>
    </message>
    <message>
        <source>An error occurred starting screensaver. Ensure you have xscreensaver installed and running.</source>
        <translation>Pri štarte šetriča obrazovky sa vyskytla chyba. Uistite sa, či je xdg-screensaver nainštalovaný a spustený.</translation>
    </message>
    <message>
        <source>An error occurred starting screensaver. Action &apos;activate&apos; failed. Ensure you have xscreensaver installed and running.</source>
        <translation>Pri štarte šetriča obrazovky sa vyskytla chyba. Operácia „activate“ zlyhala. Uistite sa, či je xdg-screensaver nainštalovaný a spustený.</translation>
    </message>
    <message>
        <source>An error occurred starting screensaver. Unknown error - undocumented return value from xdg-screensaver=%1.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>about</name>
    <message>
        <source> About Razor</source>
        <translation>O prostredí Razor</translation>
    </message>
    <message>
        <source>About</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Authors</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Thanks</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Translations</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Technical Info</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
